==> haskell-quic-0.1.6-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quic
version:              0.1.6
visibility:           public
id:                   quic-0.1.6-D6PdFYaOyOz9kjda2FTvlo
key:                  quic-0.1.6-D6PdFYaOyOz9kjda2FTvlo
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  0b6776c4db9cad13a35dc97c39210ad5
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.2.8/site-local/quic-0.1.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quic-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.6-D6PdFYaOyOz9kjda2FTvlo
depends:
    array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-FSVk3WmWsWvGvsAxOgii1R
    bytestring-0.11.4.0 containers-0.6.5.1
    crypto-token-0.0.2-CmtCqK4z9OA6ra5zq9Ga44
    crypton-0.34-LM0lFfB8WMm5ju2cCOkYtj
    crypton-x509-1.7.6-DJ3EWT7lFD0AfddJ26nJKe
    crypton-x509-system-1.6.7-9IZHO1SnVOh6NUKo1iwSlP
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    fast-logger-3.1.2-ISGKk5gJUYVDoq83Ndkycw filepath-1.4.2.2
    iproute-1.7.12-I8uTgXH9ZFf9LkSIVwfYJ9
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl
    network-byte-order-0.1.7-8Wb9MBmdsnYAp65wZlMSzk
    network-udp-0.0.0-2Cnt786KuTUBPUKn1VNvGQ
    psqueues-0.2.8.0-JrHMY66Na1LBnuuwC3aCXy
    random-1.2.1.2-63YyeAkIomQIeqEHAnFCk1 stm-2.5.0.2
    tls-1.8.0-6MSSQtWWB9s88tW1WD77BZ
    unix-time-0.4.13-96VTLj2Z2uc9GLrA9qICFz
    unliftio-0.2.25.0-JnPcGA33aKnBemmBAMXZcn
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quic-0.1.6-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quic
version:              0.1.6
visibility:           public
id:                   quic-0.1.6-IOfTNU5i8ccLoeN2grHQm
key:                  quic-0.1.6-IOfTNU5i8ccLoeN2grHQm
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  84359e00a58454cb82d7dc6e6bf46f2d
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.2.8/site-local/quic-0.1.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quic-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.6-IOfTNU5i8ccLoeN2grHQm
depends:
    array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-FSVk3WmWsWvGvsAxOgii1R
    bytestring-0.11.4.0 containers-0.6.5.1
    crypto-token-0.0.2-CmtCqK4z9OA6ra5zq9Ga44
    crypton-0.34-LM0lFfB8WMm5ju2cCOkYtj
    crypton-x509-1.7.6-DJ3EWT7lFD0AfddJ26nJKe
    crypton-x509-system-1.6.7-9IZHO1SnVOh6NUKo1iwSlP
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    fast-logger-3.1.2-giUBljIy8R8DTA38gmOH1 filepath-1.4.2.2
    iproute-1.7.12-I8uTgXH9ZFf9LkSIVwfYJ9
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl
    network-byte-order-0.1.7-8Wb9MBmdsnYAp65wZlMSzk
    network-udp-0.0.0-2Cnt786KuTUBPUKn1VNvGQ
    psqueues-0.2.8.0-JrHMY66Na1LBnuuwC3aCXy
    random-1.2.1.2-63YyeAkIomQIeqEHAnFCk1 stm-2.5.0.2
    tls-1.8.0-DKdZXhfU6DZK6tCvwpuzZM
    unix-time-0.4.14-bBaNqKOCNYBa9aAIQwFF9
    unliftio-0.2.25.0-JnPcGA33aKnBemmBAMXZcn
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
